@@ -28,7 +28,7 @@ class downloader:
         self.password=None
         self.username=None
         self.MAX_WORKERS=4
-        self.download_path="C:/ftp"
+        self.download_path=None
 
     def help(self):
         """Help documentation."""
@@ -116,6 +116,10 @@ class downloader:
                 sdate=utc.localize(sdate)
                 edate = dateparser.parse(self.end_date)
                 edate=utc.localize(edate)
+            
+            if (self.download_path==None):
+              raise Exception("Please enter a download path")
+
 
             #check date validity
             if (edate < sdate) or (sdate > datetime.now(timezone.utc)):
